.. pyEEG documentation master file, created by
   sphinx-quickstart on Mon Jan 28 17:25:13 2019.
   You can adapt this file completely to your liking, but it should at least
   contain the root `toctree` directive.

:github_url: https://github.com/Hugo-W/pyEEG

Welcome to pyEEG's documentation!
=================================

pyEEG is a wrapper around some common tooloboxes and algorithm for EEG processing with speech data.

.. toctree::
   :maxdepth: 3
   :caption: To get started

   install
   tutorials


.. toctree::
   :maxdepth: 3
   :caption: Contents

   io
   preprocess
   models
   utils
   vizu

.. toctree::
   :maxdepth: 1
   :caption: Other

   about

Indices and tables
==================

* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`

.. codeauthor:: Hugo Weissbart <hugo.weissbart12@imperial.ac.uk>
